Module core

Module core 

Structs

CustomerInteractionFields
The Airtable fields type for Customer Interactions.
DiscussionFields
The Airtable fields type for discussion topics.
JournalClubMeeting
The data type for a Journal Club Meeting.
MailingListSignupFields
The Airtable fields type for a mailing list signup.
MeetingFields
The Airtable fields type for meetings.
Paper
The data type for a paper.
ProductEmailData
The data type for sending reminders for the product huddle meetings.
RFD
The data type for an RFD.
RFDFields
The Airtable fields type for RFDs.

Statics

BASE_ID_CUSTOMER_LEADS